#!/usr/bin/perl

# (C) Sergey Kandaurov
# (C) Nginx, Inc.

# Tests for image filter module, WebP support.

###############################################################################

use warnings;
use strict;

use Test::More;

BEGIN { use FindBin; chdir($FindBin::Bin); }

use lib 'lib';
use Test::Nginx;

###############################################################################

select STDERR; $| = 1;
select STDOUT; $| = 1;

eval { require GD; };
plan(skip_all => 'GD not installed') if $@;

my $t = Test::Nginx->new()->has(qw/http image_filter/)
	->write_file_expand('nginx.conf', <<'EOF');

%%TEST_GLOBALS%%

daemon off;

events {
}

http {
    %%TEST_GLOBALS_HTTP%%

    server {
        listen       127.0.0.1:8080;
        server_name  localhost;


        location /square {
            image_filter 2square 10 10;
            alias %%TESTDIR%%/;
        }
        location /square2 {
            image_filter 2square 200 0;
            alias %%TESTDIR%%/;
        }
        location /square3 {
            image_filter 2square 110 50;
            alias %%TESTDIR%%/;
        }

    }
}

EOF

my $im = new GD::Image(100, 120);
my $white = $im->colorAllocate(255, 255, 255);
my $black = $im->colorAllocate(0, 0, 0);

$im->transparent($white);
$im->rectangle(0, 0, 99, 99, $black);

$t->write_file('gif', $im->gif);


$t->try_run('no 2square support')->plan(3);

###############################################################################


is(gif_size('/square/gif'), '30 30', 'square');
is(gif_size('/square2/gif'), '120 120', 'square 1');
is(gif_size('/square3/gif'), '210 210', 'square 2');

###############################################################################


sub gif_size {
	join ' ', unpack("x6S2", http_get_body(@_));
}

sub http_get_body {
	my ($uri) = @_;

	return undef if !defined $uri;

	my $text = http_get($uri);

	if ($text !~ /(.*?)\x0d\x0a?\x0d\x0a?(.*)/ms) {
		return undef;
	}

	return $2;
}

###############################################################################
